#########################################################################
#
# Author : Bertrand Iooss
#
# Fichier : SampleFlood.R
# Date : 2013
#
# Description:
# This function simulated a Monte Carlo sample of the flood model inputs (independent)
#
# Input: size = sample size
#
# Output: a matrix with 8 columns and "size" lines
# X[1] = Q flowrate (in m3/s), truncated gumbel max (loc=1013,scale=558,min=500,max=3000)
# X[2] = Ks Strickler coefficient, truncated Gaussian (30,8,min=15)
# X[3] = Zv (in m) downstream river bed height, triangular (50,+-1)
# X[4] = Zm (in m) upstream river bed height, triangular (55,+-1)
# X[5] = Hd (in m) dyke height, uniform (7,9)
# X[6] = Cb (in m) bank height, triangular (55.5,+-0.5)
# X[7] = L (in m) river length (between upstream and downstream), triangular (5000,+-10)
# X[8] = B (in m), triangular (300,+-5)
#
#########################################################################

library(evd)          # Gumbel law
library(triangle)     # triangular law
source("truncated.R") # for truncated laws

SampleFlood <- function(size){

	X = matrix(NA,size,8)

	X[,1] = rtgumbel(size,loc=1013.0,scale=558.0,min=500,max=3000)
	X[,2] = rtnorm(size,mean=30.0,sd=8,min=15.);
	X[,3] = rtriangle(size,a=49,b=51,c=50);
	X[,4] = rtriangle(size,a=54,b=56,c=55);
	X[,5] = runif(size,min=7,max=9);
	X[,6] = rtriangle(size,a=55,b=56,c=55.5);
	X[,7] = rtriangle(size,a=4990,b=5010,c=5000);
	X[,8] = rtriangle(size,a=295,b=305,c=300);

	return(X)

}#end function

