
# ************************************************************
# TD4

# Author: B. Iooss
# 2013

# ************************************************************

# Required packages and functions 

library(sensitivity)   # sensitivity analysis
library(evd)           # Gumbel law
library(triangle)      # triangular law

source("truncated.R")  # to define truncated laws

# Initialisation of the random seed
set.seed(12345)

# ************************************************************
# Loading the flood functions

source("Flood.R")
source("SampleFlood.R")

####################################
# Initialisation 

d <- 8 # number of inputs
names <- c("Q","Ks","Zv","Zm","Hd","Cb","L","B") # names of the inputs

# Nominal values and uncertainty (standard deviation) of the inputs
Q  <- 1335 ; sigQ  <- 716   # debit
Ks <- 30   ; sigKs <- 8     # coef de frottement
Zv <- 50   ; sigZv <- 0.41  # cote fond aval
Zm <- 55   ; sigZm <- 0.41  # cote font amont
Hd <- 8    ; sigHd <- 0.2   # hauteur de la digue
Cb <- 55.5 ; sigCb <- 0.205 # cote de la berge
L <- 5000  ; sigL  <- 4.1   # longueur de la riviere
B <- 300   ; sigB  <- 2.05  # largeur de la riviere

# Minimal and maximal values
# For min and max of Q and Ks (non bounded laws), we take 5% and 95%-quantiles
binf=c(606.6,18.7,49,54,7,55,4990,295)
bsup=c(2456.1,43.3,51,56,9,56,5010,305)

###########################################
# evaluation of the function at a nominal point
x <- t(c(Q,Ks,Zv,Zm,Hd,Cb,L,B))
source("Flood.R")
margin <- Fcrues(x)
print(c("(x,margin) = ",x,margin))
